@@ -37,4 +37,5 @@ class Extension(BaseExt):
             yield type('Charmap', (object,),
                        dict(glyphs=Extension.to_charmap(locale),
                             common_name='CLDR ' + locale.getDisplayName(),
-                            native_name='', abbreviation=locale))
+                            native_name='', abbreviation=locale,
+                            short_name='cldr-{}'.format(locale)))
