@@ -3,6 +3,8 @@ import re
 from fontaine.ext.base import BaseExt
 from fontaine.ext.update import get_from_cache
 
+import unicodedata
+
 UNIDATA_URL = 'http://www.unicode.org/Public/UNIDATA/Blocks.txt'
 
 
@@ -27,4 +29,5 @@ class Extension(BaseExt):
             yield type('Charmap', (object,),
                        dict(glyphs=unicodes,
                             common_name=u'Unicode Block %s' % m.group(3),
-                            native_name=''))
+                            native_name='',
+                            short_name=unicodedata.normalize('NFKD', u'uni-{}'.format(m.group(3).lower().replace(' ', '-')))))
