@@ -1,6 +1,7 @@
 #!/usr/bin/env python
 # coding: utf-8
-# Only pyfontain developers should use this file to update files
+# Only pyfontaine developers should use this file to update files
+import logging
 import os
 import os.path as op
 import requests
@@ -23,9 +24,17 @@ def get_data_directory():
 
 
 def get_file(name, url):
-    r = requests.get(url)
+    try:
+        r = requests.get(url)
+    except requests.exceptions.RequestException:
+        logging.warn(('Please run pyfontaine with an active internet '
+                      'connection to download all character maps'))
+        return False
     if r.status_code == 200:
-        with open(name, 'w') as f:
+        logging.warn('Updating {}'.format(name))
+        directory = get_data_directory()
+        filepath = op.join(directory, name)
+        with open(filepath, 'w') as f:
             f.write(r.content)
         return True
 
@@ -39,6 +48,7 @@ def get_from_cache(filename, url):
     return filepath
 
 
-if __name__ == '__main__':
+def bulkupdate():
     get_file('Blocks.txt', 'http://www.unicode.org/Public/UNIDATA/Blocks.txt')
     get_file('languages.xml', 'https://raw.github.com/davelab6/extensis-languages/master/languages.xml')
+    get_file('AdobeSourceSansDevanagariGlyphOrderAndAliasDB.txt', 'https://raw.githubusercontent.com/pauldhunt/source-devanagari-sans/master/GlyphOrderAndAliasDB')
